==> nextcloud-19.0.6.tgz: nextcloud/apps/settings/l10n/bs.js <==
OC.L10N.register(
    "settings",
    {
    "Saved" : "Spremljeno",
    "Email sent" : "E-pošta je poslana",
    "Public" : "Javno",
    "Unable to change password" : "Promjena lozinke nije moguća",
    "Very weak password" : "Veoma slaba lozinka",
    "Weak password" : "Slaba lozinka",
    "So-so password" : "Tu-i-tamo lozinka",
    "Good password" : "Dobra lozinka",
    "Strong password" : "Jaka lozinka",
    "Select a profile picture" : "Odaberi sliku profila",
    "Groups" : "Grupe",
    "Couldn't remove app." : "Nije moguće ukloniti aplikaciju.",
    "Couldn't update app." : "Ažuriranje aplikacije nije moguće.",
    "Wrong password" : "Pogrešna lozinka",
    "No user supplied" : "Nijedan korisnik nije dostavljen",
    "Authentication error" : "Grešna autentifikacije",
    "Wrong admin recovery password. Please check the password and try again." : "Pogrešna admin lozinka za povratak. Molim provjerite lozinku i pokušajte ponovno.",
    "You need to set your user email before being able to send test emails." : "Prije nego li ste u mogućnosti slati testnu email trebate postaviti svoj korisnički email.",
    "Invalid mail address" : "Nevažeća adresa e-pošte",
    "Unable to change full name" : "Puno ime nije moguće promijeniti",
    "Your %s account was created" : "Vaš %s račun je kreiran",
    "Apps" : "Aplikacije",
    "Settings" : "Podešavanje",
    "Personal" : "Osobno",
    "Sharing" : "Dijeljenje",
    "Create" : "Ustvari",
    "Delete" : "Izbriši",
    "Unlimited" : "Neograničeno",
    "All" : "Sve",
    "Disable" : "Onemogući",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Ova aplikacija se ne može instalirati zbog slijedećih neispunjenih ovisnosti:",
    "Rename" : "Preimenuj",
    "Username" : "Korisničko ime",
    "Password" : "Lozinka",
    "Done" : "Done",
    "Copied!" : "Kopirano",
    "Cancel" : "Odustani",
    "Email" : "E-pošta",
    "Close" : "Zatvori",
    "Quota" : "Kvota",
    "Language" : "Jezik",
    "Add" : "Dodaj",
    "Updates" : "Ažuriranja",
    "Everyone" : "Svi",
    "Admins" : "Administratori",
    "Show user backend" : "Prikaži korisničku pozadinu (backend)",
    "Send email to new user" : "Pošalji e-poštu novom korisniku",
    "Enable" : "Omogući",
    "Documentation" : "Dokumentacija",
    "Forum" : "Forum",
    "None" : "Ništa",
    "Login" : "Prijava",
    "Plain" : "Čisti tekst",
    "NT LAN Manager" : "NT LAN menedžer",
    "Send mode" : "Način rada za slanje",
    "Encryption" : "Šifriranje",
    "From address" : "S adrese",
    "mail" : "pošta",
    "Authentication method" : "Metoda autentifikacije",
    "Authentication required" : "Potrebna autentifikacija",
    "Server address" : "Adresa servera",
    "Port" : "Priključak",
    "Credentials" : "Vjerodajnice",
    "SMTP Username" : "SMTP Korisničko ime",
    "SMTP Password" : "SMPT Lozinka",
    "Save" : "Spremi",
    "Test email settings" : "Postavke za testnu e-poštu",
    "Send email" : "Pošalji e-poštu",
    "Version" : "Verzija",
    "Allow apps to use the Share API" : "Dozvoli aplikacijama korištenje Share API",
    "Expire after " : "Istek nakon",
    "days" : "dana",
    "Enforce expiration date" : "Nametni datum isteka",
    "Allow users to share via link" : "Dozvoli korisnicima dijeljenje putem veze",
    "Allow public uploads" : "Dozvoli javno učitavanje",
    "Enforce password protection" : "Nametni zaštitu lozinke",
    "Allow resharing" : "Dopustite ponovno dijeljenje",
    "Restrict users to only share with users in their groups" : "Ograniči korisnike na međusobno dijeljenje resursa samo s korisnicima unutar svoje grupe",
    "Exclude groups from sharing" : "Isključite grupe iz dijeljenja",
    "These groups will still be able to receive shares, but not to initiate them." : "Ove će grupe i dalje moći primati dijeljene resurse, ali ne i inicirati ih",
    "Profile picture" : "Slika profila",
    "Upload new" : "Učitaj novu",
    "Remove image" : "Ukloni sliku",
    "Your email address" : "Vaša adresa e-pošte",
    "Address" : "Adresa",
    "Website" : "Web-prezentacija",
    "Help translate" : "Pomozi prevesti",
    "Current password" : "Trenutna lozinka",
    "New password" : "Nova lozinka",
    "Change password" : "Promijeni lozinku",
    "Valid until {date}" : "Validno do {date}",
    "Local" : "Lokalno",
    "Contacts" : "Kontakti",
    "by" : "od strane",
    "Common Name" : "Opće Ime",
    "Valid until" : "Validno do",
    "Issued By" : "Izdano od",
    "Valid until %s" : "Validno do %s",
    "Execute one task with each page loaded" : "Izvrši jedan zadatak sa svakom učitanom stranicom"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-21.0.3.tgz: nextcloud/apps/settings/l10n/bs.js <==
OC.L10N.register(
    "settings",
    {
    "Saved" : "Spremljeno",
    "Email sent" : "E-pošta je poslana",
    "Local" : "Lokalno",
    "Unable to change password" : "Promjena lozinke nije moguća",
    "Very weak password" : "Veoma slaba lozinka",
    "Weak password" : "Slaba lozinka",
    "So-so password" : "Tu-i-tamo lozinka",
    "Good password" : "Dobra lozinka",
    "Strong password" : "Jaka lozinka",
    "Select a profile picture" : "Odaberi sliku profila",
    "Groups" : "Grupe",
    "Couldn't remove app." : "Nije moguće ukloniti aplikaciju.",
    "Couldn't update app." : "Ažuriranje aplikacije nije moguće.",
    "Wrong password" : "Pogrešna lozinka",
    "No user supplied" : "Nijedan korisnik nije dostavljen",
    "Authentication error" : "Grešna autentifikacije",
    "Wrong admin recovery password. Please check the password and try again." : "Pogrešna admin lozinka za povratak. Molim provjerite lozinku i pokušajte ponovno.",
    "You need to set your user email before being able to send test emails." : "Prije nego li ste u mogućnosti slati testnu email trebate postaviti svoj korisnički email.",
    "Invalid mail address" : "Nevažeća adresa e-pošte",
    "Unable to change full name" : "Puno ime nije moguće promijeniti",
    "Your %s account was created" : "Vaš %s račun je kreiran",
    "Apps" : "Aplikacije",
    "Settings" : "Podešavanje",
    "Personal" : "Osobno",
    "Sharing" : "Dijeljenje",
    "Create" : "Ustvari",
    "Delete" : "Izbriši",
    "Unlimited" : "Neograničeno",
    "All" : "Sve",
    "Disable" : "Onemogući",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Ova aplikacija se ne može instalirati zbog slijedećih neispunjenih ovisnosti:",
    "Rename" : "Preimenuj",
    "Username" : "Korisničko ime",
    "Password" : "Lozinka",
    "Done" : "Done",
    "Copied!" : "Kopirano",
    "Cancel" : "Odustani",
    "Email" : "E-pošta",
    "Quota" : "Kvota",
    "Language" : "Jezik",
    "Add" : "Dodaj",
    "Updates" : "Ažuriranja",
    "Everyone" : "Svi",
    "Admins" : "Administratori",
    "Show user backend" : "Prikaži korisničku pozadinu (backend)",
    "Send email to new user" : "Pošalji e-poštu novom korisniku",
    "Enable" : "Omogući",
    "Documentation" : "Dokumentacija",
    "Forum" : "Forum",
    "None" : "Ništa",
    "Login" : "Prijava",
    "Plain" : "Čisti tekst",
    "NT LAN Manager" : "NT LAN menedžer",
    "Send mode" : "Način rada za slanje",
    "Encryption" : "Šifriranje",
    "From address" : "S adrese",
    "Authentication method" : "Metoda autentifikacije",
    "Authentication required" : "Potrebna autentifikacija",
    "Server address" : "Adresa servera",
    "Port" : "Priključak",
    "Credentials" : "Vjerodajnice",
    "SMTP Username" : "SMTP Korisničko ime",
    "SMTP Password" : "SMPT Lozinka",
    "Save" : "Spremi",
    "Test email settings" : "Postavke za testnu e-poštu",
    "Send email" : "Pošalji e-poštu",
    "Version" : "Verzija",
    "Allow apps to use the Share API" : "Dozvoli aplikacijama korištenje Share API",
    "days" : "dana",
    "Enforce expiration date" : "Nametni datum isteka",
    "Allow public uploads" : "Dozvoli javno učitavanje",
    "Enforce password protection" : "Nametni zaštitu lozinke",
    "Allow resharing" : "Dopustite ponovno dijeljenje",
    "Restrict users to only share with users in their groups" : "Ograniči korisnike na međusobno dijeljenje resursa samo s korisnicima unutar svoje grupe",
    "Exclude groups from sharing" : "Isključite grupe iz dijeljenja",
    "These groups will still be able to receive shares, but not to initiate them." : "Ove će grupe i dalje moći primati dijeljene resurse, ali ne i inicirati ih",
    "Profile picture" : "Slika profila",
    "Upload new" : "Učitaj novu",
    "Remove image" : "Ukloni sliku",
    "Your email address" : "Vaša adresa e-pošte",
    "Address" : "Adresa",
    "Website" : "Web-prezentacija",
    "Help translate" : "Pomozi prevesti",
    "Current password" : "Trenutna lozinka",
    "New password" : "Nova lozinka",
    "Change password" : "Promijeni lozinku",
    "Valid until {date}" : "Validno do {date}",
    "Contacts" : "Kontakti",
    "Public" : "Javno",
    "by" : "od strane",
    "Close" : "Zatvori",
    "Common Name" : "Opće Ime",
    "Valid until" : "Validno do",
    "Issued By" : "Izdano od",
    "Valid until %s" : "Validno do %s",
    "mail" : "pošta",
    "Execute one task with each page loaded" : "Izvrši jedan zadatak sa svakom učitanom stranicom",
    "Expire after " : "Istek nakon",
    "Allow users to share via link" : "Dozvoli korisnicima dijeljenje putem veze"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
